@@ -21,7 +21,7 @@ from erioon.delete import handle_delete_one, handle_delete_many
 from erioon.update import handle_update_one, handle_update_many, handle_replace_one
 from erioon.ping import handle_connection_ping
 from erioon.vector import handle_vector_similarity_search
-from erioon.ai import handle_deep_search
+# from erioon.ai import handle_deep_search
 
 class Collection:
     def __init__(
